==> core-1.0.0.tgz: package/lib/class-names/label-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiComponentProps } from '../ui-component-props/ui-component-props';
export const labelLayoutClassNamesConfig = {
    prefix: 'cck-label',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-label'
            ],
            description: 'It will add to the host element of Label component.'
        },
        labelTag: {
            name: 'Label Element',
            selectors: [
                'cck-label__label-tag'
            ],
            description: 'It will add to the `label` element of html tag'
        },
        requiredMarker: {
            name: 'Required Marker Element',
            selectors: [
                'cck-label__required-marker'
            ],
            description: 'It will add to the to the required marker element, when the `hideRequiredMarker` of `FormField` component is `false`. It will show the `*` at end of label text'
        }
    }
};
export function getLabelClassNames(componentProps, uiComponentsConfig) {
    const options = {
        componentName: 'label',
        componentProps,
        uiComponentsConfig
    };
    validateUiComponentProps(options);
    return {
        host: [
            ...labelLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(labelLayoutClassNamesConfig.prefix, options)
        ],
        labelTag: [
            ...labelLayoutClassNamesConfig.elements.labelTag.selectors
        ],
        requiredMarker: [
            ...labelLayoutClassNamesConfig.elements.requiredMarker.selectors
        ]
    };
}

==> core-1.1.0.tgz: package/lib/class-names/label-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiBaseComponentProps } from '../ui-component-props/ui-component-props';
export const labelLayoutClassNamesConfig = {
    prefix: 'cck-label',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-label'
            ],
            description: 'It will add to the host element of Label component.'
        },
        labelTag: {
            name: 'Label Element',
            selectors: [
                'cck-label__label-tag'
            ],
            description: 'It will add to the `label` element of html tag'
        },
        requiredMarker: {
            name: 'Required Marker Element',
            selectors: [
                'cck-label__required-marker'
            ],
            description: 'It will add to the to the required marker element, when the `hideRequiredMarker` of `FormField` component is `false`. It will show the `*` at end of label text'
        }
    }
};
export function getLabelClassNames(componentProps, themeConfig) {
    const options = {
        componentName: 'label',
        componentProps,
        themeConfig
    };
    validateUiBaseComponentProps(options);
    return {
        host: [
            ...labelLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(labelLayoutClassNamesConfig.prefix, options)
        ].join(' '),
        labelTag: [
            ...labelLayoutClassNamesConfig.elements.labelTag.selectors
        ].join(' '),
        requiredMarker: [
            ...labelLayoutClassNamesConfig.elements.requiredMarker.selectors
        ].join(' ')
    };
}
